Description
===========

This is PythonTurtle module in polish commands


Instalation
===========

For the module to work properly, you need python version 3.11 (or higher)

Windows 10/11
Please open cmd or PowerShell and write:
 pip install TurtlePolish

MacOS
Please open command line and write:
 python -m pip install TurtlePolish

Thanks to
=========

DaytimeSpore380